@@ -7,6 +7,8 @@ from zope.interface import implements
 from zope.viewlet.interfaces import IViewlet
 from zope import component
 
+from plonehrm.contracts.content.contract import ContractHourSpread
+
 def compare_dates(a, b):
     return cmp(a.getStartdate(), b.getStartdate())
 
@@ -387,3 +389,18 @@ class ContractViewlet(Explicit, ContractView):
         if base is None or base == self:
             return 0
         return base.getDaysPerWeek()
+
+    def default_hour_spread(self):
+        """ Returns the ContractHourSpread object linked to the contract.
+        """
+        base = self.base_contract()
+        if base is None or base == self:
+            return ContractHourSpread()
+        return base.hour_spread
+
+    def is_arbo_manager(self):
+        """ Checks if the user has arbo manager rights.
+        """
+        membership = getToolByName(self.context, 'portal_membership')
+        return membership.checkPermission('plonehrm: manage Arbo content',
+                                          self.context)
