@@ -286,7 +286,8 @@ class ContractKssView(KSSView):
                          'contract_viewlet_workdays_no_integer',
                          'contract_viewlet_incorrect_workdays',
                          'contract_viewlet_spread_to_high',
-                         'contract_viewlet_more_than_24']:
+                         'contract_viewlet_more_than_24',
+                         'contract_viewlet_invalid_hour_spread']:
             selector = core.getHtmlIdSelector(errorMsg)
             core.setAttribute(selector, 'class', 'dont-show')
 
@@ -321,6 +322,8 @@ class ContractKssView(KSSView):
 
         self._validate_field(number_hours, 'contract_viewlet_hours_no_integer',
                          'int', errors)
+        if not number_hours:
+            number_hours = 0
 
         try:
             tmp = int(workdays)
@@ -342,13 +345,16 @@ class ContractKssView(KSSView):
 
             for row in rows:
                 for day in range(0, 7):
-                    try:
-                        field = float(form['schedule_' + row + '_' + str(day)])
-                    except:
-                        field = 0
-                    if field in form:                           
-                        total += field
-                        if field > 24:
+                    field = 'schedule_' + row + '_' + str(day)
+
+                    if field in form:
+                        try:
+                            field_value = float(form[field])
+                        except ValueError:
+                            errors.append(
+                                'contract_viewlet_invalid_hour_spread')
+                        total += field_value
+                        if field_value > 24:
                             errors.append('contract_viewlet_more_than_24')
 
             if rows:
