@@ -432,5 +432,29 @@ class Contract(BaseContent):
 
         return metadata['hour_spread']
 
+    def getHoursPerWeek(self):
+        """ Returns the number of hours worked each week.
+        """
+        # Check if the user has Arbo rights.
+        membership = getToolByName(self, 'portal_membership')
+        is_arbo =  membership.checkPermission('plonehrm: manage Arbo content',
+                                              self)
+
+        if not is_arbo:
+            return self.getHours()
+
+        odd_weeks = 0
+        even_weeks = 0
+
+        for hour in self.hour_spread.hours:
+            if hour.startswith('odd'):
+                odd_weeks += self.hour_spread.hours[hour]
+            else:
+                even_weeks += self.hour_spread.hours[hour]
+
+        if odd_weeks == even_weeks:
+            return str(int(odd_weeks))
+        else:
+            return str(int(odd_weeks)) + '/' + str(int(even_weeks))
 
 registerType(Contract, config.PROJECTNAME)
