@@ -37,7 +37,10 @@ def apply_template(object, event, rename=True):
     resulting_text = view.substitute(template_text)
     object.setText(resulting_text)
 
-    # Set the title.
+    # Set the title to the title of the template (appending 1, 2,
+    # 3...), if it has not been set explicitly.
+    if object.Title():
+        return
     employee = object.get_employee()
     title = template_page.Title()
     if employee is not None:
